==> apache-beam-2.35.0-source-release.zip: beam-2.35.0/playground/frontend/lib/modules/output/components/output_area.dart <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import 'package:flutter/material.dart';
import 'package:playground/modules/output/components/output_result.dart';
import 'package:playground/pages/playground/states/playground_state.dart';
import 'package:provider/provider.dart';

const kLogText = 'Log';
const kGraphText = 'Graph';

class OutputArea extends StatelessWidget {
  const OutputArea({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      color: Theme.of(context).backgroundColor,
      child: Consumer<PlaygroundState>(
        builder: (context, state, child) {
          return TabBarView(
            physics: const NeverScrollableScrollPhysics(),
            children: <Widget>[
              OutputResult(text: state.result?.output ?? ''),
              const Center(child: Text(kLogText)),
              const Center(child: Text(kGraphText)),
            ],
          );
        },
      ),
    );
  }
}

==> apache-beam-2.36.0-source-release.zip: beam-2.36.0/playground/frontend/lib/modules/output/components/output_area.dart <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import 'package:flutter/material.dart';
import 'package:flutter_gen/gen_l10n/app_localizations.dart';
import 'package:playground/modules/output/components/output_result.dart';
import 'package:playground/pages/playground/states/playground_state.dart';
import 'package:provider/provider.dart';

class OutputArea extends StatelessWidget {
  final TabController tabController;

  const OutputArea({Key? key, required this.tabController}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      color: Theme.of(context).backgroundColor,
      child: Consumer<PlaygroundState>(
        builder: (context, state, child) {
          return TabBarView(
            controller: tabController,
            physics: const NeverScrollableScrollPhysics(),
            children: <Widget>[
              OutputResult(
                text: state.result?.output ?? '',
                isSelected: tabController.index == 0,
              ),
              OutputResult(
                text: state.result?.log ?? '',
                isSelected: tabController.index == 1,
              ),
              Center(child: Text(AppLocalizations.of(context)!.graph)),
            ],
          );
        },
      ),
    );
  }
}
